@@ -47,7 +47,7 @@ NULL
 #' segments.
 #' @param draw_sd *geom*. Toggles drawing of the standard deviation interval
 #' lines and segments.
-#' @param midline_color *geom*. Color of the vertical, center line. Set to `NA`
+#' @param midline *geom*. Color of the vertical, center line. Set to `NA`
 #' to omit the line.
 #' @param brighten *geom*. Numeric adjustments to the fill color. A value above
 #' 1 increases brightness, below decreases. Should be of length 1 or 5,
@@ -195,7 +195,7 @@ example_plot <- function() {
       draw_ci=TRUE, # toggle showing confidence interval parts
       draw_sd=TRUE, # toggle showing standard deviation parts
       mirror=FALSE, # toggle horizontal violin distributions
-      midline_color=NULL, # line displaying center of dist. (NULL=aes color)
+      midline=NULL, # line displaying center of dist. (NULL=aes color)
       brighten=c(3, 0, 1.333), # additive adjustment of segment fill colors
       # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
       # position_spread() options
@@ -208,12 +208,12 @@ example_plot <- function() {
       # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
       # standard ggplot layer options
       # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-      size=0.15, color=colors$gray, vjust=0.7, show.legend=FALSE) +
+      size=0.15, color=colors$gray, vjust=0.7, show.legend=FALSE
+    ) +
 
     # standard ggplot2 elements ------------------------------------------------
-    geom_vline(
-      alpha=0.5, color=colors$gray, size=0.333, linetype=1,
-      xintercept=0) + scale_x_continuous(breaks=seq(-1, 1, .05)) +
+    geom_vline(alpha=0.5, color=colors$gray, size=0.333, linetype=1, xintercept=0) +
+    scale_x_continuous(breaks=seq(-1, 1, .05)) +
     facet_grid("contrast ~ .", scales="free_y", space="free_y") +
     scale_fill_manual(values=c(colors$yellow, colors$magenta, colors$cyan)) +
     labs(x="Difference in accuracy (posterior predictions)") +
@@ -221,5 +221,6 @@ example_plot <- function() {
       legend.position="none", strip.text.y=element_text(angle=0, hjust=0.5),
       panel.border=element_rect(fill=NA, color=colors$lightgray, size=0.67),
       panel.grid=element_blank(), panel.ontop=FALSE, axis.title.y=element_blank(),
-      plot.margin=margin(t=2, r=4, b=2, l=2, unit="pt"))
+      plot.margin=margin(t=2, r=4, b=2, l=2, unit="pt")
+    )
 }
